#ifndef ENEMIGO_H
#define ENEMIGO_H

#include <Gosu/Gosu.hpp>
#include "Nivel.h"
#include "Constantes.h"
#include <vector>

/// @brief Clase Enemigo.
///
/// Esta clase servirá para representar a los enemigos.																
/// @author Rodríguez Quirós, Estefanía
/// @version 0.1

using namespace std;

class Nivel;
class Ventana;

class Enemigo {
   public:
	   /// @brief Crea un objeto de la clase Enemigo
	   /// @return Objeto inicializado de la clase Enemigo
      Enemigo(Gosu::Graphics& graphics, int movX_min, int movX_max, int movY, int width, int height, int velX = 0 );
		/// @brief Elimina un objeto Enemigo y libera su espacio en memoria.
      virtual ~Enemigo();
		/// @brief Devuelve el lugar donde el enemigo comienza su recorrido en el nivel.
		/// @return Atributo movX1_ que contiene el margen izquiero de la zona en la que el enemigo se mueve.
      int movX1();
		/// @brief Devuelve el lugar donde el enemigo termina su recorrido en el nivel.
		/// @return Atributo movX2_ que contiene el margen derecho de la zona en la que el enemigo se mueve.
      int movX2();
		/// @brief Devuelve la posición en el eje y del enemigo en el nivel.
		/// @return Atributo movY_ que contiene la posición en el eje y del enemigo en el nivel.
      int movY();
		/// @brief Devuelve el ancho del enemigo.
		/// @return Atributo width_ que contine los píxeles de ancho del enemigo.
      int width();
		/// @brief Devuelve el alto del enemigo.
		/// @return Atributo height_ que contiene los píxeles de alto del enemigo.
      int height();
		/// @brief Devuelve la posición en el eje x del nivel en la que se encuentra el enemigo. 
		/// @return Atributo pos_ que contiene la posición en el eje x del nivel en la que se encuentra el enemigo.
      int posicion();
		/// @brief Modifica la posición en el eje x en la que se encuentra el enemigo.
      void posicion(int pos);
		/// @brief Indica si el enemigo se mueve hacia la derecha (0) o hacia la izquierda (1).
		/// @return 0 si el enemigo se está moviendo hacia la derecha y 1 si lo hace hacia la izquierda.
      int direccion();
		/// @brief Cambia la dirección en la que se mueve el enemigo.
      void direccion(int dir);
		/// @brief Se usa para modificar la imagen del enemigo cuando se mueve hacia la derecha.
		/// @return Varía entre 0 y 1 para usar dicho número como iterador en un vector que servirá para variar la imagen del enemigo.
      int palader();
		/// @brief Se usa para modificar la imagen del enemigo cuando se mueve hacia la izquierda.
		/// @return Varía entre 0 y 1 para usar dicho número como iterador en un vector que servirá para variar la imagen del enemigo.
      int palaizq();
		/// @brief Devuelve la velocidad horizontal del enemigo.
		/// @return Atributo velX_ que contiene la velocidad horizontal del enemigo.
      int velX();

	  	pair<vector<Gosu::Image*>,int> control_der() const;
		pair<vector<Gosu::Image*>,int> control_izq() const;
	
		pair<vector<Gosu::Image*>,int>& control_der();
		pair<vector<Gosu::Image*>,int>& control_izq();
		
		
   private:
      vector<Gosu::Image*> enemy_der_,enemy_izq_;
      int movX1_,movX2_,movY_,width_,height_,pos_;

      int dir_,der_,izq_;
      int velX_;
      
   protected:
	   pair<vector<Gosu::Image*>,int> control_der_,control_izq_; /// Más adelante habŕa que ponerlo privado, e implementar métodos set() y get().
};



/// @brief Clase Abeja.
///
/// Esta clase servirá para representar a una abeja, un tipo de Enemigo.
/// @author Ruso Amieva, Antonio
/// @version 0.1

class Abeja : virtual public Enemigo
{
   public:
      Abeja(Gosu::Graphics& graphics, int movX_min, int movX_max, int movY);
};

/// @brief Clase Mosca

class Mosca : virtual public Enemigo
{
   public:
      Mosca(Gosu::Graphics& graphics, int movX_min, int movX_max, int movY);
};

/// @brief Clase Cucaracha

class Cucaracha : virtual public Enemigo
{
   public:
      Cucaracha(Gosu::Graphics& graphics, int movX_min, int movX_max, int movY);
};

#endif
