#ifndef NIVEL_H
#define NIVEL_H

#include <Gosu/Gosu.hpp>
//#include <Gosu/AutoLink.hpp> Este es para Windows
#include "Aranya.h"
#include "Enemigo.h"
#include "Obstaculo.h"
#include "Mosquito.h"
#include <vector>
#include <iostream>

using namespace std;

class Aranya;
class Enemigo;
class Obstaculo;

class Nivel
{
	public:
		Nivel (Gosu::Graphics& graphics, int nivel);
		~Nivel ();
		int width() const;
		int height() const;
		int suelo() const; // Lo he puesto por poner, al final lo quitaremos
		int nivel () const;
		Gosu::Image* fondo() const;
      /// @brief Comprueba si hay obstáculos justo a la derecha de la araña.
		/// @return Iterador que apunta al obstáculo con el que la araña colisiona por la derecha de la araña; Obstaculos_.end() si no hay ninguno.
      vector<Obstaculo*>::iterator HayObstaculoDer(Aranya *minyimi);
		/// @brief Comprueba si hay obstáculos justo a la izquierda de la araña.
		/// @return Iterador que apunta al obstáculo con el que la araña colisiona por la izquierda de la araña; Obstaculos_.end() si no hay ninguno.
      vector<Obstaculo*>::iterator HayObstaculoIzq(Aranya *minyimi);
		/// @brief Comprueba si hay obstáculos justo a la derecha de la araña.
		/// @return Iterador que apunta al obstáculo con el que la araña colisiona por arriba de la araña; Obstaculos_.end() si no hay ninguno.
      vector<Obstaculo*>::iterator HayObstaculoArriba(Aranya *minyimi);
		/// @brief Comprueba si hay obstáculos justo a la derecha de la araña.
		/// @return Iterador que apunta al obstáculo con el que la araña colisiona por debajo de la araña; Obstaculos_.end() si no hay ninguno.
      vector<Obstaculo*>::iterator HayObstaculoAbajo(Aranya *minyimi);

		/// @brief Comprueba si hay enemigos justo a la derecha de la araña.
		/// @return Verdadero si se encuentra un enemigo justo a la derecha de la araña y falso en caso contrario.
      bool HayEnemigoDer();
		/// @brief Comprueba si hay enemigos justo a la izquierda de la araña.
		/// @return Verdadero si se encuentra un enemigo justo a la izquierda de la araña y falso en caso contrario.
      bool HayEnemigoIzq();
		/// @brief Comprueba si hay enemigos justo arriba de la araña.
		/// @return Verdadero si se encuentra un enemigo justo arriba de la araña y falso en caso contrario.
      bool HayEnemigoArriba();
		/// @brief Comprueba si hay enemigos justo abajo de la araña.
		/// @return Verdadero si se encuentra un enemigo justo abajo de la araña y falso en caso contrario.
      bool HayEnemigoAbajo();
		bool MuereMinyimiMuere(Aranya *minyimi);
		vector<Obstaculo*>& Obstaculos();
		vector<Enemigo*>& Enemigos();
		vector<Mosquito*>& Mosquitos();
		void draw (int x, int y = 0, int z = 0);
		void mover_enemigos(int desplazamiento);
		void mover_mosquitos(int desplazamiento);
		bool Comida(Aranya *minyimi);
//		Gosu::Song *music();
	private:
		int nivel_,width_,height_,suelo_;
		Gosu::Image *fondo_;
		Gosu::Song *music_;
      vector<Enemigo*> Enemigos_;
      vector<Obstaculo*> Obstaculos_;
      vector<Mosquito*> Mosquitos_;
};


class Menu
{
	public:
		Menu (Gosu::Graphics& graphics);
		~Menu();
		Gosu::Image* fondo() const; // se quita
		Gosu::Image* jugar() const;
		Gosu::Image* salir() const;
		void draw(double x, double y);
		void pararMusica();
		void niveles(double x, double y);
		int escogernivel(int ratonx, int ratony);
	private:
		Gosu::Image *fondo_,*bjugar1_,*bjugar2_,*bsalir1_,*bsalir2_,*nivel11_,*nivel12_,*nivel21_,*nivel22_,*nivel31_,*nivel32_,*nivel41_,*nivel42_;
		Gosu::Song *music_;
};

#endif

